@@ -1,7 +1,6 @@
 import numpy as np
 import mne
 import matplotlib.pyplot as plt
-import matplotlib.colors as mcolors
 import matplotlib.gridspec as gridspec
 from types import SimpleNamespace
 from .helpers import (_compute_tep_peaks, _neigh_correction,
@@ -17,19 +16,19 @@ class TEP:
                  p1_range=[0.01, 0.04], low_limit=35,
                  sign_corr='convexity'):
         """
-        Initialize TEP object with automatic peak computation
-
+        Initialize a TEP object and compute peaks.
+        
         Args:
-            epochs: mne.Epochs object
-            exclude_channels: Channels to exclude
-            p1_range: Time window for first peak detection (s)
-            low_limit: Maximum frequency (Hz) considered for peak separation.
-                Determines the minimum time interval between consecutive peaks as:
-                    min_interval = 1/(low_limit * 2) seconds
-                Lower values enforce stricter temporal separation (wider peak spacing).
-                Higher values allow closer peak detection (tighter peak spacing).
-                (Default: 35 Hz ≈ 14 ms separation)
-            sign_corr: Method for signal correction
+            epochs (mne.Epochs): Input epochs.
+            exclude_channels (list[str] | None): Channel names to drop before processing.
+            p1_range (list[float, float]): Search window for the first peak P1 in seconds.
+                Default: [0.01, 0.04].
+            low_limit (float): Maximum frequency (Hz) used to enforce a minimum separation
+                between consecutive peaks:
+                    min_interval = 1 / (2 * low_limit)  [seconds]
+                Lower values enforce wider spacing; higher values allow closer peaks.
+                Default: 35 (≈14 ms).
+            sign_corr (str): Method for signal sign correction. Default: 'convexity'.
         """
         # Process epochs
         if exclude_channels:
@@ -93,21 +92,48 @@ class TEP:
     # Core Data Access Methods
     # -------------------------
     def get_epo(self, pick_ch=None):
-        """Return epochs data (epochs × channels × time)"""
+        """
+        Return epoched data as a NumPy array.
+        
+        Args:
+            pick_ch (list[str | int] | None): Channel names or indices to select.
+                If None, all channels are returned.
+        
+        Returns:
+            np.ndarray: Shape (n_epochs, n_channels_selected, n_times), in µV.
+        """
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
             return self.epochs.get_data()[:, ch_idxs]
         return self.epochs.get_data()
 
     def get_tep(self, pick_ch=None):
-        """Return averaged TEP data (channels × time)"""
+        """
+        Return the averaged TEP (Evoked) data as a NumPy array.
+        
+        Args:
+            pick_ch (list[str | int] | None): Channel names or indices to select.
+                If None, all channels are returned.
+        
+        Returns:
+            np.ndarray: Shape (n_channels_selected, n_times), in µV.
+        """
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
             return self.tep_data.get_data()[ch_idxs]
         return self.tep_data.get_data()
 
     def get_gmfp(self, pick_ch=None):
-        """Return global(local) mean field power data (time)"""
+        """
+        Return the (global or local) mean field power over channels.
+                
+        Args:
+            pick_ch (list[str | int] | None): Channel names or indices to define a local
+                GMFP. If None, all channels are used (global GMFP).
+        
+        Returns:
+            np.ndarray: Shape (n_times,), in µV.
+        """
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
             return np.sqrt(np.mean(self.tep_data.get_data()[ch_idxs] ** 2, 0))
@@ -117,20 +143,19 @@ class TEP:
     # Feature Access Methods
     # -------------------------
     def get_amplitudes(self, pick_ch=None, ntop=4, neighbors_correction=True, verbose=False):
-        """Get peak amplitudes (P1, P2, P3)
-
+        """
+        Get peak amplitudes for P1, P2, P3.
+        
         Args:
-            pick_ch: Channels to select (list of names or indices). Overrides ntop.
-            ntop: Number of top channels to return (ignored if pick_ch is used)
-            - None: Returns all channels (unsorted)
-            - int: Returns top N channels sorted by P1-P2 amplitude
-                   (must be between 1 and total channel count)
-            neighbors_correction: Apply spatial correction in the ntop selection
-            verbose: Print selection details
-
+            pick_ch (list[str | int] | None): Channel names or indices to select.
+                If provided, `ntop` is ignored and channels are returned in the given order.
+            ntop (int | None): Number of channels to return, ranked by P1–P2 peak-to-peak
+                amplitude. If None, all channels are returned unsorted.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            verbose (bool): Print selection details.
+        
         Returns:
-            Array of channel peak amplitudes with shape (channels x 3), where the 
-                second dimension correspond to P1, P2, and P3 amplitudes, respectively.
+            np.ndarray: Shape (n_channels_selected, 3), columns = [P1, P2, P3] in µV.
         """
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
@@ -149,20 +174,19 @@ class TEP:
         return self.amp_peaks[idxs_ntop]
 
     def get_latencies(self, pick_ch=None, ntop=4, neighbors_correction=True, verbose=False):
-        """Get peak latencies (P1, P2, P3) in seconds
-
+        """
+        Get peak latencies for P1, P2, P3.
+        
         Args:
-            pick_ch: Channels to select (list of names or indices). Overrides ntop.
-            ntop: Number of top channels to return (ignored if pick_ch is used)
-            - None: Returns all channels (unsorted)
-            - int: Returns top N channels sorted by P1-P2 amplitude
-                   (must be between 1 and total channel count)
-            neighbors_correction: Apply spatial correction in the ntop selection
-            verbose: Print selection details
-
+            pick_ch (list[str | int] | None): Channel names or indices to select.
+                If provided, `ntop` is ignored and channels are returned in the given order.
+            ntop (int | None): Number of channels to return, ranked by P1–P2 peak-to-peak
+                amplitude. If None, all channels are returned unsorted.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            verbose (bool): Print selection details.
+        
         Returns:
-            Array of channel peak latencies with shape (channels x 3), where the 
-                second dimension correspond to P1, P2, and P3 latencies, respectively.
+            np.ndarray: Shape (n_channels_selected, 3), columns = [P1, P2, P3] in seconds.
         """
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
@@ -181,20 +205,21 @@ class TEP:
         return self.lat_peaks[idxs_ntop]
 
     def get_peaktopeak(self, pick_ch=None, ntop=4, neighbors_correction=True, verbose=False):
-        """Get peak-to-peak amplitudes (P1-P2, P2-P3)
-
+        """
+        Get peak-to-peak amplitudes.
+        
+        Computes P1–P2 and P2–P3 peak-to-peak amplitudes.
+        
         Args:
-            pick_ch: Channels to select (list of names or indices). Overrides ntop.
-            ntop: Number of top channels to return (ignored if pick_ch is used)
-            - None: Returns all channels (unsorted)
-            - int: Returns top N channels sorted by P1-P2 amplitude
-                   (must be between 1 and total channel count)
-            neighbors_correction: Apply spatial correction in the ntop selection
-            verbose: Print selection details
-
+            pick_ch (list[str | int] | None): Channel names or indices to select.
+                If provided, `ntop` is ignored and channels are returned in the given order.
+            ntop (int | None): Number of channels to return, ranked by P1–P2 peak-to-peak
+                amplitude. If None, all channels are returned unsorted.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            verbose (bool): Print selection details.
+        
         Returns:
-            Array of channel peak-to-peak amplitudes with shape (channels x 2), where the 
-                second dimension correspond to P1-P2, and P2-P2 peak-to-peak amplitudes, respectively.
+            np.ndarray: Shape (n_channels_selected, 2), columns = [P1–P2, P2–P3] in µV.
         """
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
@@ -213,19 +238,19 @@ class TEP:
         return self.amp_p2p[idxs_ntop]
 
     def get_interpeak(self, pick_ch=None, ntop=4, neighbors_correction=True, verbose=False):
-        """Get interpeak intervals (P3-P1) in seconds
-
+        """
+        Get the inter-peak interval P3–P1.
+        
         Args:
-            pick_ch: Channels to select (list of names or indices). Overrides ntop.
-            ntop: Number of top channels to return (ignored if pick_ch is used)
-            - None: Returns all channels (unsorted)
-            - int: Returns top N channels sorted by P1-P2 amplitude
-                   (must be between 1 and total channel count)
-            neighbors_correction: Apply spatial correction in the ntop selection
-            verbose: Print selection details
-
+            pick_ch (list[str | int] | None): Channel names or indices to select.
+                If provided, `ntop` is ignored and channels are returned in the given order.
+            ntop (int | None): Number of channels to return, ranked by P1–P2 peak-to-peak
+                amplitude. If None, all channels are returned unsorted.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            verbose (bool): Print selection details.
+        
         Returns:
-            Array of channel interpeak.
+            np.ndarray: Shape (n_channels_selected,), values = P3–P1 interval in seconds.
         """
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
@@ -244,20 +269,22 @@ class TEP:
         return self.interpeak[idxs_ntop]
 
     def get_slope_peaks(self, pick_ch=None, ntop=4, neighbors_correction=True, verbose=False):
-        """Get slope between subsequent peaks (P1-P2, P2-P3). The unit is µV/ms
-
+        """
+        Get slopes between consecutive peaks (µV/ms).
+        
+        Computes the slopes between P1–P2 and P2–P3:
+            slope = (Δamplitude) / (Δlatency), with latency in milliseconds.
+        
         Args:
-            pick_ch: Channels to select (list of names or indices). Overrides ntop.
-            ntop: Number of top channels to return (ignored if pick_ch is used)
-            - None: Returns all channels (unsorted)
-            - int: Returns top N channels sorted by P1-P2 amplitude
-                   (must be between 1 and total channel count)
-            neighbors_correction: Apply spatial correction in the ntop selection
-            verbose: Print selection details
-
+            pick_ch (list[str | int] | None): Channel names or indices to select.
+                If provided, `ntop` is ignored and channels are returned in the given order.
+            ntop (int | None): Number of channels to return, ranked by P1–P2 peak-to-peak
+                amplitude. If None, all channels are returned unsorted.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            verbose (bool): Print selection details.
+        
         Returns:
-            Array of channel slopes with shape (channels x 2), where the 
-                second dimension correspond to P1-P2, and P2-P3 slopes, respectively.
+            np.ndarray: Shape (n_channels_selected, 2), columns = [P1–P2, P2–P3] in µV/ms.
         """
         slope = lambda x1, y1, x2, y2: np.divide((y2 - y1), (x2 - x1),
                                                  out=np.full_like(x1, np.inf, dtype=float),
@@ -288,16 +315,16 @@ class TEP:
     # Info selected channels
     # -------------------------
     def get_ntop_ch(self, ntop=4, neighbors_correction=True, verbose=False):
-        """Get top channel names based on P1-P2 amplitude
-
+        """
+        Get names of the top channels ranked by P1–P2 peak-to-peak amplitude.
+        
         Args:
-            ntop: Number of top channels to return.
-            - int: Returns top N channels sorted by P1-P2 amplitude
-            neighbors_correction: Apply spatial correction in the ntop selection
-            verbose: Print selection details
-
+            ntop (int): Number of channels to return.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            verbose (bool): Print selection details.
+        
         Returns:
-            Array of channel names.
+            np.ndarray: Channel names, shape (ntop,).
         """
         ntop = _validate_ntop(ntop, self.info.n_channels)
         idxs_ntop = self.get_ntop_idx(
@@ -309,17 +336,21 @@ class TEP:
         return self.ch_names[idxs_ntop]
 
     def get_ntop_idx(self, ntop=4, neighbors_correction=True, return_orig=False, verbose=False):
-        """Get top channel indices based on P1-P2 amplitude
-
+        """
+        Get indices of the top channels ranked by P1–P2 peak-to-peak amplitude.
+        
         Args:
-            ntop: Number of top channels to return.
-            - int: Returns top N channels sorted by P1-P2 amplitude
-            neighbors_correction: Apply spatial correction in the ntop selection
-            return_orig: Return both corrected and original indices
-            verbose: Print selection details
-
+            ntop (int): Number of channels to return.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            return_orig (bool): If True, also return the pre-correction indices.
+            verbose (bool): Print selection details.
+        
         Returns:
-            idxs_ntop (and optionally idxs_ntop_orig).
+            np.ndarray | tuple[np.ndarray, np.ndarray]:
+                If `return_orig` is False:
+                    idxs_ntop: shape (ntop,)
+                If `return_orig` is True:
+                    (idxs_ntop, idxs_ntop_orig), each shape (ntop,).
         """
         # Get P1-P2 amplitudes (first column of amp_p2p)
         amp_p1p2 = self.amp_p2p[:, 0]
@@ -346,20 +377,23 @@ class TEP:
             return idxs_ntop
 
     def info_ntop(self, ntop=4, neighbors_correction=True, verbose=False, ):
-        """Get comprehensive info about top channels
-
+        """
+        Summarize information about the top channels.
+        
         Args:
-            ntop: Number of top channels.
-            neighbors_correction: Apply spatial correction Apply spatial correction in the ntop selection.
-            verbose: Print selection details (default: False).
-
-        Returns dictionary with:
-            - channels: Corrected channel names (if neighbors_correction is applied)
-            - channels_original: Original channel names (before correction)
-            - amplitudes: Peak amplitudes
-            - latencies: Peak latencies
-            - peak_to_peak: P1-P2 and P2-P3 amplitudes
-            - interpeaks: P3-P1 intervals
+            ntop (int): Number of channels to summarize.
+            neighbors_correction (bool): Enforce spatial contiguity of the ntop channels.
+            verbose (bool): Print selection details.
+        
+        Returns:
+            dict: With keys
+                - 'channels' (list[str]): Corrected top channel names.
+                - 'channels_original' (list[str]): Original (pre-correction) channel names.
+                - 'amplitudes' (np.ndarray): Shape (ntop, 3), [P1, P2, P3] in µV.
+                - 'latencies' (np.ndarray): Shape (ntop, 3), [P1, P2, P3] in seconds.
+                - 'peak_to_peak' (np.ndarray): Shape (ntop, 2), [P1–P2, P2–P3] in µV.
+                - 'interpeaks' (np.ndarray): Shape (ntop,), P3–P1 in seconds.
+                - 'slopes' (np.ndarray): Shape (ntop, 2), [P1–P2, P2–P3] in µV/ms.
         """
         ntop = _validate_ntop(ntop, self.info.n_channels)
         idxs_ntop, idxs_ntop_orig = self.get_ntop_idx(
@@ -384,37 +418,30 @@ class TEP:
     # -------------------------
     def plot_summary(self, ntop=4, tlim=(-100, 300), title='',
                      neighbors_correction=True, verbose=False,
-                     cmap_topo='viridis', topo_lim=(0, None), table_max_ch=4):
+                     cmap_topo='viridis', topo_lim=(0, None), contours=3, table_max_ch=4):
         """
-        Generate a comprehensive summary plot of TEP analysis on the selected channels
-
-        The plot contains three panels:
-        1. Time series: Shows TEP waveforms for top channels with detected peaks
-        2. Latency table: Displays peak latencies for top channels
-        3. Topographic map: Visualizes P1-P2 amplitude distribution
-
+        Generate a summary figure for the TEP analysis on the selected channels.
+        
+        The figure includes:
+            1) Time series of the averaged TEP for the top channels with detected peaks.
+            2) A table of P1–P2–P3 latencies for the top channels.
+            3) A topographic map of the P1–P2 peak-to-peak amplitude.
+        
         Args:
-            ntop: Number of top channels to display (default=4)
-            tlim: Time limits for time series plot in milliseconds (default=(-100, 300))
-            title: Main title for the plot (default='')
-            neighbors_correction: Apply spatial neighbor correction to channel selection (default=True)
-            verbose: Print channel selection details (default=False)
-            cmap_topo: Colormap for topographic plot (default='Reds')
-            topo_lim: Color limits for topographic plot as (vmin, vmax) (default=(0, None))
-            table_max_ch: Maximum number of channels reported in the table (max number of rows)
-
+            ntop (int): Number of top channels to display. Default: 4.
+            tlim (tuple[float, float]): Time limits for the TEP plot in milliseconds.
+            title (str): Figure title. Default: ''.
+            neighbors_correction (bool): Enforce spatial contiguity of the top channels.
+            verbose (bool): Print selection details.
+            cmap_topo (str): Colormap for the topography. Default: 'viridis'.
+            topo_lim (tuple[float | None, float | None]): Color scale limits (vmin, vmax).
+                Use None to auto-scale. Default: (0, None).
+            contours (int): (int | array_like): The number of contour lines to draw. 
+                ne.viz.plot_topomap
+            table_max_ch (int): Maximum number of rows displayed in the latency table.
+        
         Returns:
-            matplotlib.figure.Figure: The generated figure object
-
-        Example:
-            fig = tep.plot_summary(
-                ntop=5,
-                tlim=(-50, 250),
-                title="Subject 01 - TEP Summary",
-                cmap_topo='viridis',
-                topo_lim=(0, 10)
-            )
-            fig.savefig('tep_summary.png')
+            matplotlib.figure.Figure: The created figure.
         """
 
         ntop = _validate_ntop(ntop, self.info.n_channels)
@@ -468,7 +495,7 @@ class TEP:
         ax3 = fig.add_subplot(gs[1, 1])
         amp_p1p2 = self.amp_p2p[:, 0]
         im, cn = mne.viz.plot_topomap(amp_p1p2, self.epochs.info, axes=ax3, names=self.ch_names,
-                                      sensors=False, cmap=cmap_topo, vlim=topo_lim, contours=3)
+                                      sensors=False, cmap=cmap_topo, vlim=topo_lim, contours=contours)
         cax = fig.colorbar(im, ax=ax3, shrink=0.5)
         cax.set_label(f'peak-to-peak ($\\mu$V)', fontsize=8)
 
