@@ -14,21 +14,22 @@ class TimeFreq:
                  ch_names=None, method=None, baseline_correction=None, 
                  baseline_range=None, computed_on_epochs=None, 
                  sfreq=None, tep_data=None):
-        """Initialize TimeFreq object
+        """
+        Initialize TimeFreq object with time-frequency analysis results.
         
         Args:
-            freqs: Frequency vector (1D array) in Hz
-            times: Time vector (1D array) in seconds
-            power: Power spectrum array (4D: epochs × channels × freqs × times)
-            itc: Inter-trial coherence array (3D: channels × freqs × times) or None
-            complex_coeff: Complex time-frequency coefficients (4D) or None
-            ch_names: Channel names
-            method: Method used ('stock1' or 'stock2')
-            baseline_correction: Whether baseline correction was applied
-            baseline_range: Baseline time range used (if any)
-            computed_on_epochs: Whether time-frequency was computed on single trials (epochs)
-            sfreq: Sampling frequency (Hz)
-            tep_data: TEP data
+            freqs (array_like): Frequency vector (1D array) in Hz.
+            times (array_like): Time vector (1D array) in seconds.
+            power (np.ndarray): Power spectrum array (4D: epochs × channels × freqs × times).
+            itc (np.ndarray): Inter-trial coherence array (3D: channels × freqs × times).
+            complex_coeff (np.ndarray): Complex time-frequency coefficients (4D).
+            ch_names (list of str): Channel names.
+            method (str): Method used ('stock1' or 'stock2').
+            baseline_correction (bool): Whether baseline correction was applied.
+            baseline_range (tuple): Baseline time range [start, end] in seconds.
+            computed_on_epochs (bool): Whether computed on single trials (epochs).
+            sfreq (float): Sampling frequency in Hz.
+            tep_data (object): TEP data object containing sensor information.
         """
         # Core data arrays
         self.freqs = freqs
@@ -83,14 +84,15 @@ class TimeFreq:
     # Core Access Methods
     # -------------------------
     def get_power(self, pick_ch=None, average_channels=False):
-        """Get time-frequency power
+        """
+        Retrieve time-frequency power data.
     
         Args:
-            pick_ch: Channel name or list of channel names to include (default: None, all channels included)
-            average_channels: Average the channels before returning (default: False)
+            pick_ch (list[str | int] | None): Channel names or indices to select. If None, all channels are returned.
+            average_channels (bool): If True, average across selected channels before returning.
     
         Returns:
-            power: time-frequency power array. Dimensions depend on `pick_ch`, `average_channels`
+            np.ndarray: Power array with dimensions depending on `pick_ch` and `average_channels`.
         """
         power_data = self.power.copy()
         if pick_ch is not None:
@@ -101,14 +103,15 @@ class TimeFreq:
         return power_data
     
     def get_itc(self, pick_ch=None, average_channels=False):
-        """Get inter-trial coherence (ITC)
+        """
+        Retrieve inter-trial coherence (ITC).
     
         Args:
-            pick_ch: Channel name or list of channel names to include (default: None, all channels included)
-            average_channels: Average the channels before returning (default: False)
-            
+            pick_ch (list[str | int] | None): Channel names or indices to select. If None, all channels are returned.
+            average_channels (bool): If True, average across selected channels before returning. 
+    
         Returns:
-            itc: ITC array. Dimensions depend on `pick_ch`, `average_channels`
+            np.ndarray or None: ITC array with dimensions depending on `pick_ch` and `average_channels`. Returns None if ITC was not computed.
         """
         if self.itc is None:
             print("ITC has not been computed.")
@@ -122,18 +125,19 @@ class TimeFreq:
         return itc_data
     
     def get_complex(self, pick_ch=None):
-        """Get complex coefficients of the stockwell transform
+        """
+        Retrieve complex coefficients of the Stockwell transform.
     
         Args:
-            pick_ch: Channel name or list of channel names to include (default: None, all channels included)
-            
+            pick_ch (list[str | int] | None): Channel names or indices to select. If None, all channels are returned.
+    
         Returns:
-            complex data: complex coefficients array. Dimensions depend on `pick_ch`
+            np.ndarray or None: Complex coefficient array with dimensions depending on `pick_ch`. Returns None if complex coefficients are not available.
         """
         if self.complex_coeff is None:
             print("Complex coefficients are not available.")
             return None
-        complex_data = self.complex_data.copy()
+        complex_data = self.complex_coeff.copy()
         if pick_ch is not None:
             ch_idxs = _validate_pick_ch(pick_ch, self.ch_names)
             complex_data = complex_data[:,ch_idxs]
@@ -143,21 +147,23 @@ class TimeFreq:
     # Analysis Methods
     # -------------------------
     def get_evoked_spectrum(self, pick_ch=None, average_channels=True, sum_window=(0.02,0.12), baseline_range=(-0.5,-0.1), return_power=False):
-        """Compute the evoked spectrum as the sum of time–frequency power over a specified time window
-        
+        """
+        Compute evoked power spectrum by summing time-frequency power over a specified time window.
+    
         Args:
-            pick_ch: Channel name or list of channel names to include (default: None, all channels included)
-            average_channels: Average the channels before computing the spectrum (default: True) 
-            sum_window: Start and end times (s) over which to sum the power (default: (0.02, 0.12))
-            baseline_range: Time range (s) for baseline correction, used only if baseline correction
-                has not already been applied to the TimeFreq object (default: (-0.5, -0.1))
-            
+            pick_ch (list[str | int] | None): Channel name(s) to include. If None, all channels are included.
+            average_channels (bool): Average channels before computing spectrum.
+            sum_window (tuple of float): Start and end times (s) to sum the power. 
+            baseline_range (tuple of float): Time range (s) for baseline correction if not already applied. 
+            return_power (bool): If True, also return the baseline-corrected time-frequency power array 
+                from which the evoked power spectrum is derived.
+
         Returns:
-            evoked_power: Power summed (or integrated) over the specified `sum_window`
-                Dimensions depend on `pick_ch`, `average_channels`
+            np.ndarray or tuple: Evoked power spectrum 1D array (freqs,); 
+                                 optionally a tuple (evoked_power, baseline-corrected time-frequency power).
         
         Notes:
-            Baseline subtraction is applied only if it has not been previously applied
+            Baseline subtraction is applied only if not already applied in the TimeFreq object.
         """
         power_data = self.power.copy()
         if not self.info.baseline_correction:
@@ -176,17 +182,18 @@ class TimeFreq:
 
     
     def get_natfreq(self, natfreq_window=(0.02,0.12), pick_ch=None, average_channels=True, baseline_range=(-0.5,-0.1)):
-        """Compute natural frequency as frequency with max power in the evoked power.
+        """
+        Compute the natural frequency as the frequency with maximal power in the evoked power spectrum.
     
         Args:
-            natfreq_window: Time window for analysis [start, end] in seconds.
-            pick_ch: Channels to include (default: None = all).
-            average_channels: Average the power across channels before computation (default: True).
-            baseline_range: Time range (s) for baseline correction, used only if baseline correction
-                has not already been applied to the TimeFreq object (default: (-0.5, -0.1))
+            natfreq_window (tuple of float): Time window (s) used to compute the natural frequency. 
+                It corresponds to the summation window of the evoked power spectrum. 
+            pick_ch (list[str | int] | None): Channel name(s) to include. If None, all channels are included.
+            average_channels (bool): If True, average power across channels before analysis. 
+            baseline_range (tuple of float): Time range (s) for baseline correction if not already applied.
     
         Returns:
-            Natural frequency (Hz)
+            float: Natural frequency (Hz) corresponding to the peak of the evoked power.
         """
         evoked_spectrum = self.get_evoked_spectrum(pick_ch=pick_ch, average_channels=average_channels, 
                                                    sum_window=natfreq_window, baseline_range=baseline_range)
@@ -203,38 +210,51 @@ class TimeFreq:
                       color_spectrum='tab:blue', color_butterfly='gray',
                       cmap='RdBu_r', plot_ms=True, figsize=(7,6), dpi=300,
                       label_cbar=r'$\Delta$power ($\mu V^2$)'):        
-        """Plot natural frequency analysis (multi-panel version).
-    
-        Includes:
-            - Butterfly plot of TEPs
-            - Sensor topography
-            - Time-frequency representation
-            - Evoked spectrum with frequency bands
-    
+        """
+        Plot natural frequency analysis (multi-panel version).
+        
+        The figure includes:
+            1) Butterfly plot of TEPs with highlighted channels
+            2) Sensor topography of selected channels
+            3) Time-frequency representation
+            4) Evoked spectrum with frequency bands
+        
         Args:
-            natfreq_window: Time window for natural frequency [start, end] in seconds.
-            pick_ch: Channels for TF computation (default: None = all).
-            baseline_range: Time range (s) for baseline correction, used only if baseline correction
-                has not already been applied to the TimeFreq object (default: (-0.5, -0.1))
-            plot_tlim: Plot time limits (s).
-            ch_tep: Channels to highlight in butterfly plot.
-            ch_lab_tep: Labels for highlighted channels.
-            ch_color_tep: Colors for highlighted channels.
-            color_spectrum: Color for frequency bands.
-            color_butterfly: Color for background TEPs.
-            cmap: Colormap for time-frequency plot.
-            plot_ms: Display time in milliseconds (default: True).
-            figsize: Figure dimensions.
-            dpi: Figure resolution.
-            label_cbar: Colorbar label.
-    
+            natfreq_window (tuple of float): Time window (s) used to compute the natural frequency. 
+                It corresponds to the summation window of the evoked power spectrum. 
+            pick_ch (list[str | int] | None): Channel name(s) to include. If None, all channels are included.
+            baseline_range (tuple of float): Time range (s) for baseline correction if not already applied.
+            plot_tlim (tuple): Plot time limits [start, end] in seconds.
+            ch_tep (list[str | int] | None): Channel name(s) to highlight in butterfly plot. 
+                If None, all the channels in the TimeFreq object are highlighted.
+            ch_lab_tep (list[str | int] | None): Labels for highlighted channels.
+                If None, the labels of the channels in the TimeFreq object are used.
+            ch_color_tep (list of str | None): Colors for highlighted channels.
+                It should have the same length of ch_tep. If None, colors from XKCD palette are used.
+            color_spectrum (str): Color for frequency bands. Default: 'tab:blue'.
+            color_butterfly (str): Color for background TEPs. Default: 'gray'.
+            cmap (str): Colormap for time-frequency plot. Default: 'RdBu_r'.
+            plot_ms (bool): Display time in milliseconds. Default: True.
+            figsize (tuple): Figure dimensions in inches. Default: (7,6).
+            dpi (int): Figure resolution. Default: 300.
+            label_cbar (str): Colorbar label. Default: r'$\Delta$power ($\mu V^2$)'.
+        
         Returns:
-            matplotlib.figure.Figure: Generated figure.
+            matplotlib.figure.Figure: The generated figure object.
+
+        Notes:
+            - `pick_ch` uses the channels present in the TimeFreq object (the channels used for time-frequency computation)
+            - `ch_tep` uses all channels from the original TEP data object, which may differ from TimeFreq channels
+            - Best practice is to use `ch_tep=None` to highlight exactly the same channels used for time-frequency analysis
+            - When selecting a single channel with `pick_ch`, to highlight its TEP provide the channel name (str) in 
+              `ch_tep` to ensure correct matching
+            - Channel indices may differ between TimeFreq and TEP objects - using names (str) is more reliable than indices
         """
         # prepare data
         bands, bands_lab = _return_bands_idxs(self.freqs)
         if any(sum(b) <= 1 for b in bands):
-            raise ValueError(f"Insufficient frequency bands detected. Requires theta to gamma range (or alpha to gamma range). Actual frequency range {f"{self.freqs[0]:.1f}-{self.freqs[-1]:.1f}Hz"}")
+            raise ValueError(f"Insufficient frequency bands detected. Requires theta to gamma range (or alpha to gamma range). Actual frequency range {self.freqs[0]:.1f}-{self.freqs[-1]:.1f}Hz")
+
         evoked_spectrum, power_data = self.get_evoked_spectrum(pick_ch=pick_ch, 
                                                        average_channels=True, 
                                                        sum_window=natfreq_window, 
@@ -354,27 +374,28 @@ class TimeFreq:
                       color_spectrum='tab:blue', cmap='RdBu_r', 
                       plot_ms=True, figsize=(6,3), dpi=300,
                       label_cbar=r'$\Delta$power ($\mu V^2$)'):
-        """Plot natural frequency analysis (compact version).
-    
-        Includes:
-            - Time-frequency representation
-            - Evoked spectrum with frequency bands
-    
+        """
+        Plot natural frequency analysis (compact version).
+        
+        The figure includes:
+            1) Time-frequency representation
+            2) Evoked spectrum with frequency bands
+        
         Args:
-            natfreq_window: Time window for natural frequency [start, end] in seconds.
-            pick_ch: Channels for TF computation (default: None = all).
-            baseline_range: Time range (s) for baseline correction, used only if baseline correction
-                has not already been applied to the TimeFreq object (default: (-0.5, -0.1))
-            plot_tlim: Plot time limits (s).
-            color_spectrum: Color for frequency bands.
-            cmap: Colormap for time-frequency plot.
-            plot_ms: Display time in milliseconds (default: True).
-            figsize: Figure dimensions in inches.
-            dpi: Figure resolution.
-            label_cbar: Colorbar label.
-    
+            natfreq_window (tuple of float): Time window (s) used to compute the natural frequency. 
+                It corresponds to the summation window of the evoked power spectrum. 
+            pick_ch (list[str | int] | None): Channel name(s) to include. If None, all channels are included.
+            baseline_range (tuple of float): Time range (s) for baseline correction if not already applied.
+            plot_tlim (tuple): Plot time limits [start, end] in seconds.
+            color_spectrum (str, optional): Color for frequency bands. Default: 'tab:blue'.
+            cmap (str, optional): Colormap for time-frequency plot. Default: 'RdBu_r'.
+            plot_ms (bool, optional): Display time in milliseconds. Default: True.
+            figsize (tuple, optional): Figure dimensions in inches. Default: (6,3).
+            dpi (int, optional): Figure resolution. Default: 300.
+            label_cbar (str, optional): Colorbar label. Default: r'$\Delta$power ($\mu V^2$)'.
+        
         Returns:
-            matplotlib.figure.Figure: Generated figure.
+            matplotlib.figure.Figure: The generated figure object.
         """
         # prepare data
         bands, bands_lab = _return_bands_idxs(self.freqs)
